function sbatchmode(testproblem)
%SBATCHMODE enables batch processing for S-IFISS testproblem
%   sbatchmode(testproblem);
%   input
%          testproblem  character string naming the testproblem
%                       must have the form "stoch*_batch".m 
%   side effect
%          If batchmode terminates prematurely because of an error or
%          execution of cntl-C, interactive input with S-IFISS may not
%          work correctly.  This is fixed by typing "activemode".
%
% The workspace is saved in the file batchrun.mat
% type "load batchrun" to revover it after the batch run finishes
%
%   SIFISS function: DJS; 26 March 2015.
% Copyright (c) 2015 A. Bespalov, C.E. Powell, D.J. Silvester


global BATCH FID

% file containing input data 
batchfile=[testproblem,'_batch.m']
[FID,message]=fopen(batchfile,'r');
% Error return on nonexistent or misnamed input file
if strcmp(message,'')~=1
   error(['INPUT FILE ERROR: ' message])
else
   disp(['Working in batch mode from data file ' batchfile])
end
if ~strncmp(testproblem,'stoch',5),
    errmsg = 'INPUT FILE ERROR:\n';
    errmsg = [errmsg,'   Batch input filename should be "stoch*_batch.m"'];
    error('BATCH:err',errmsg);    
end  

% batch run
% switch to activate batch mode (off/on 0/1) (see "default.m")
BATCH=1;

% run driver
   stoch_diff_testproblem
   gohome, cd datafiles, save batchrun.mat


% switch back to interactive mode
activemode
return
