%STOCH_CHANNEL_DIFF solves stochastic diffusion problem in channel flow domain 
%   SIFISS scriptfile: DJS; DJS; 4 July 2017.
% Copyright (c) 2013 A. Bespalov, C.E. Powell, D.J. Silvester
gohome, cd datafiles
save stoch_data.mat rd_type checkcode
% load geometry
spde=1; domain=101;
load stoch_channel_grid.mat

  % define stochastic approximation
  norv=13;
  noarv=default('Number of random variables? (default is 3)',3);
  if noarv > norv, error('Oops.. need to increase parameter norv!'), end
     if noarv>0,
     polyd=default('Total polynomial degree? (default is 2)',2);
     [indset] = stoch_indset(polyd,noarv);
     indset = [indset,zeros(length(indset),norv-noarv)];
else
% set up the default index set
def_indset=[0 0; 0 1; 1 0];
%  def_indset=[zeros(1,6);eye(6)];
%  for k=2:6
%      def_indset=[def_indset;def_indset(k,:)+def_indset(k+1,:)];
%  end
   indset=default('Input index set of polynomial degrees? (accept default)',def_indset);
   noarv=length(indset(1,:));
   polyd=max(max(indset));
     if  polyd>=2^8-1,
     error('Oops.. polynomial degree is too high for uint8 arithmetic!'), end
   indset = uint8([indset,zeros(length(indset),norv-noarv)]);
end
%
% sort the index set
  indset=sortrows(indset);
%  
% find the length of the index set and the number of random variables
  [P,norv] = size(indset);   % P=p+1 if norv=1
%
% find the number of active random variables
  noarv = norv - nnz(all(indset==0,1));

% special case: indset = [0 0 ... 0]
  if P==1 && nnz(indset)==0
     norv = 0; indset = [0];
  end

% find x_min, x_max, y_min, y_max
  x_min = min(xy(:,1)); x_max = max(xy(:,1));
  y_min = min(xy(:,2)); y_max = max(xy(:,2));

% compute the KL-expansion data if needed
gohome, cd datafiles
load stoch_data  %% load rd_type checkcode
  if rd_type == 1 && norv > 0
% check that domain is symmetric w.r.t. the origin
     if x_min + x_max == 0 && y_min + y_max == 0
         fprintf('setting up KL expansion data\n')
        std_dev=default('standard deviation? (default 0.24)',2.4e-01);
        correl_x=default('correlation length in x-direction? (default 1.0)',1.0e-00);
        correl_y=default('correlation length in y-direction? (default 1.0)',1.0e-00);
        KL_DATA = stoch_kl_eigens(x_max,y_max,std_dev,correl_x,correl_y,norv);
     else
        error('the domain must be symmetric with respect to the origin!')
     end
  else
      fprintf('using synthetic random coefficient expansion\n')
     KL_DATA.input = [1,1,0];
  end

% save the data related to KL-expansion
  save stoch_kl_data.mat '-struct' KL_DATA
  
% set the spatial approximation
  qmethod=default('Q1/Q2 approximation 1/2? (default Q1)',1);

% generate the G-matrices
G = stoch_gmatrices(indset,P,noarv,norv);

% setup and solve the discrete system
  fprintf('MINRES solution of the linear system ... \n')
  tol=1e-10; maxit=99;
  apost=0; stopit=0; prob_type='sdiff';
  if qmethod==1,
     [ev,ebound] = q1grid(xy,mv,bound,mbound);
     [Knbc,fnbc] = stoch_femq1_setup(xy,ev,indset,P,norv,noarv,KL_DATA);
  elseif qmethod ==2,  
     [x,y,xy] = q2grid(x,y,xy,mv,bound);
     [Knbc,fnbc] = stoch_femq2_setup(xy,mv,indset,P,norv,noarv,KL_DATA);
  else
      error('Oops.. the approximation is not available!')
  end
  [K,fnew,x_gal,dupl_intern] = stoch_imposebc(Knbc,fnbc,G,xy,bound,indset,P,norv,noarv);
%    [K,fnew,x_gal,dupl_intern] = stoch_imposebc_old(Knbc,fnbc,xy,bound,indset,P,norv,noarv);

   nint=length(dupl_intern)/P;
   % extract the mean stiffness matrix
   Amean=K{1}; % imposed boundary conditions
   [LA,UA]=lu(Amean); 
   MA='m_sdiff'; aparams=struct('nint',nint,'L',LA,'U',UA);
   [xminres,resvec,emin, errpde, info]= ...
       stoch_est_minres(G,K,fnew,apost,stopit,maxit,tol,...
                         prob_type,MA,aparams);
   x_gal(dupl_intern)=xminres;
   
 %  plot convergence data
   figure(13)
   inx=0:info(4)-1;rx=9:9:info(4);
   if info(4)>4,
   semilogy(inx,sqrt(2)*resvec./emin,'-r');
   hold on
   semilogy(inx,resvec,'-b');
   hold off
   axis('square')
   xlabel('iteration number {\it k}')
   title('MINRES convergence history')
   h=legend('${\sqrt{2}/ \lambda_k^2}\> ||r_k||_{M_*}$','$||r_k||_{M_*}$');
   set(h,'Interpreter','latex')
   end
fprintf('linear solver statistics:\n')
 fprintf('total ndof is %g\nminimum eigenvalue is %8.3f\n',length(x_gal),emin(end))
 fprintf('stochastic parameters:\n')
 fprintf('%g active random variables | polynomial degree is %2i\n',noarv,polyd)
 fprintf('\n')


% compute variance
  nvtx=length(xy(:,1));
  var_sol=stoch_variance(x_gal,P);
  fprintf('\nComputed statistics ...\nmaximum mean value is %8.3e ',...
        max(x_gal(1:nvtx)) );
  fprintf('\nmaximum variance is %8.3e \n\n',max(var_sol));


% compute a posteriori error estimate
  fprintf('\n')
  stoch_diffpostx

% plot expectation, variance and YP-error estimate
  if qmethod ==1,
     stoch_errplot_q1(x_gal,yp_err_el,ev,xy,x,y,P,noarv,111),
     stoch_errplot_q1(x_gal,xq_err_el,ev,xy,x,y,P,noarv,114),
  elseif qmethod==2,
     stoch_errplot_q2(x_gal,mv,xy,x,y,P,noarv,112),
     stoch_errplot_q2x(x_gal,yp_err_el,mv,xy,x,y,P,noarv,121),
     stoch_errplot_q2x(x_gal,xq_err_el,mv,xy,x,y,P,noarv,124),
  end
fprintf('To test other detail space options .. run stoch_diffpostx\n')
fprintf('To test legacy estimation code .. run stoch_diffpost\n')
