function [B] = stoch_new_indset(A,noarv)
%STOCH_ADAPT_NEW_INDSET  computes the augmented index set of 'neighbouring' indices
% [indset_augmented] = stoch_new_indset(indset,noarv);
%   input
%          noarv              the number of active random variables
%          indset             given index set (a matrix with non-negative integer components)
%   output
%          indset_augmented   augmented index set
%
%   S-IFISS function: DJS; 14 June 2017
% Copyright (c) 2014 A. Bespalov, C.E. Powell, D.J. Silvester

% dd is number of new parameters to probe
dd=1;

% dimensions of A
  [P,norv] = size(A);

% check that noarv < norv
  if noarv >= norv, error('error: increase the number of random variables!'), end

  I = eye(noarv+dd,'uint8');

% augment I with zero columns on the right to match size(A,2)
  I = [I,zeros(noarv+dd,norv-noarv-dd)];

  B = A;

% Find new entries of the index set for each row of A
  for i = 1 : P
      B = [B;A(i*ones(1,noarv+dd),:) + I];
  end

% Cancel duplicating rows in B
  B = unique(B(1:size(B,1),:),'rows');

end

