function [edgeres] = stoch_edgeres_q2_yqx(xy,mv,mbound,q2sol,eex,hx,hy,indset1,P1,indset2,noarv,KL_DATA)
%STOCH_EDGERES_Q2_YQX  computes YQX edge residuals for stochastic Q2 solution
%   [edgeres] = stoch_edgeres_q2_yqx(xy,mv,mbound,q2sol,eex,hx,hy,indset1,P1,indset2,noarv,KL_DATA);
%   input
%          xy           vertex coordinate vector
%          mv           element mapping matrix
%          mbound       element edge boundary matrix
%          q2sol        stochastic Q1 solution vector
%          eex          element edge connectivity array
%          hx,hy        element mesh sizes
%          indset1      first index set (for the stochastic solution)
%          P1           length of the first index set
%          indset2      second index set (for the error estimator)
%          noarv         number of random variables
%          KL_DATA      data related to KL-expansion
%   output
%          edgeres      edge residuals
%
%   calls functions q2fluxjmps, gausspoints_oned, stoch_gauss_coeff, qqderiv
%   SIFISS function: DJS; 5 July 2017
% Copyright (c) 2013 A. Bespalov, C.E. Powell, D.J. Silvester

neumannb=[];
%% taken from diffpost_q2_with_q4
reduction_level=3;
error_node=[10;11;12;13;14;15;16;17;18;20;22;24];
N_error_node=length(error_node); nn=N_error_node;

  x=xy(:,1); y=xy(:,2); nvtx=length(x);
  mel=length(mv(:,1));
  [P2,noarv] = size(indset2);

% construct the integration rule
ngpt=7;  ng=ngpt;
  [oneg,onew] = gausspoints_oned(ngpt);

% initialisation
  edgeres = zeros(mel,nn*P2);
  temp_res = zeros(mel,nn,P1,noarv+1);
  xl_v=nan(mel,4); yl_v=nan(mel,4);

% inner loop over elements
  for ivtx = 1:4
      xl_v(:,ivtx) = x(mv(:,ivtx));
      yl_v(:,ivtx) = y(mv(:,ivtx)); 
  end


% loop over Gauss points
   for igpt=1:ngpt
   sigpt=oneg(igpt);
   wigpt=onew(igpt);
% save coefficient data
   coeff_1 = stoch_gauss_coeff(sigpt,-1,xl_v,yl_v,noarv,KL_DATA);
   [qua_1,dquadx_v,dquady_v] = qqderiv(sigpt,-1,xl_v,yl_v);
%
   coeff_2 = stoch_gauss_coeff(1,sigpt,xl_v,yl_v,noarv,KL_DATA);
   [qua_2,dquadx_v,dquady_v] = qqderiv(1,sigpt,xl_v,yl_v);
%
   coeff_3 = stoch_gauss_coeff(sigpt,1,xl_v,yl_v,noarv,KL_DATA);
   [qua_3,dqardx_v,dqardy_v] = qqderiv(sigpt,1,xl_v,yl_v);
%
   coeff_4 = stoch_gauss_coeff(-1,sigpt,xl_v,yl_v,noarv,KL_DATA);
   [qua_4,dquadx_v,dquady_v] = qqderiv(-1,sigpt,xl_v,yl_v);
%
%  loop over indices in the index set
      for k=1:P1
      njmp = q2fluxjmps(q2sol((k-1)*nvtx+1:k*nvtx,1),eex,xy,mv,mbound,neumannb,sigpt);
%     loop over detail space basis functions
         for ee = 1:N_error_node
            eei=error_node(ee);
            if eei==1| eei==10| eei==5| eei==11| eei==2
            for m = 0:noarv % loop over stochastic variables
               temp_res(:,ee,k,m+1) = temp_res(:,ee,k,m+1)+(1/2)*wigpt*coeff_1(:,m+1).*njmp(:,1).*qua_1(:,eei).*hx(:)*(1/2);
               end
            elseif eei==2| eei==12| eei==6| eei==13| eei==3
            for m = 0:noarv % loop over stochastic variables
               temp_res(:,ee,k,m+1) = temp_res(:,ee,k,m+1)+(1/2)*wigpt*coeff_2(:,m+1).*njmp(:,2).*qua_2(:,eei).*hy(:)*(1/2);
               end
             elseif eei==3| eei==14| eei==7| eei==15| eei==4
             for m = 0:noarv % loop over stochastic variables
                temp_res(:,ee,k,m+1) = temp_res(:,ee,k,m+1)+(1/2)*wigpt*coeff_3(:,m+1).*njmp(:,3).*qua_3(:,eei).*hx(:)*(1/2);
                end
             elseif eei==4| eei==16| eei==8| eei==17| eei==1
             for m = 0:noarv % loop over stochastic variables
                temp_res(:,ee,k,m+1) = temp_res(:,ee,k,m+1)+(1/2)*wigpt*coeff_4(:,m+1).*njmp(:,4).*qua_4(:,eei).*hy(:)*(1/2);
                end
             end
          end    % end of detail space basis functions
       end       % end of the loop over indices in the index set
    end          % end of Gauss points loop

% compute G-matrices
  G = stoch_gmatrices_new(indset1,indset2);

% building edge residual vectors
   for m = 0:noarv
   [nzi,nzj,g] = find(G{m+1});
      for t=1:length(nzi)
      i=nzi(t); j=nzj(t);
      edgeres(:,(nn*(i-1)+1):nn*i) = edgeres(:,(nn*(i-1)+1):nn*i) + g(t)*temp_res(:,1:nn,j,m+1);
      end
   end

  return
