function stoch_errplot_q2(sol,ev,xy,x,y,P,noarv,fig)
%STOCH_ERRPLOT_Q2 plots solution data on rectangular domain for Q2 elements
%   stoch_errplot_q2(sol,ev,xy,x,y,P,noarv,fig);
%   input
%          sol          nodal stochatic FE solution vector
%          ev           element mapping matrix
%          xy           vertex coordinate vector  
%          x            vector of x-axis interpolation points
%          y            vector of y-axis interpolation points
%          P            length of the index set
%          noarv        the number of active random variables
%          fig          figure number
%
%   IFISS function: DJS; 5 July 2017.
% Copyright (c) 2013 A. Bespalov, C.E. Powell, D.J. Silvester

  fprintf('plotting expectation and variance ... ')

  nvtx = length(xy);

% interpolate to a cartesian product mesh
  [X,Y] = meshgrid(x,y);

% plot the expectation of the solution
  e_xysol = griddata(xy(:,1),xy(:,2),sol(1:nvtx),X,Y);
  figure(fig)
  subplot(221),contour(X,Y,e_xysol,20),axis('square')
  axis('off'),  title('Expectation of the FE Solution')
  subplot(222),mesh(X,Y,e_xysol),axis('square')
  view(330,30)

% compute variance of the solution
  var_sol=stoch_variance(sol,P);

% plot variance of the solution
  var_xysol = griddata(xy(:,1),xy(:,2),var_sol(1:nvtx),X,Y);
  subplot(223),contour(X,Y,var_xysol,20),axis('square')
  axis('off'),  title('Variance of the FE Solution')
  subplot(224),mesh(X,Y,var_xysol),axis('square')
  view(330,30)

  fprintf('done\n')
  return

