function stoch_errplot_q2x(sol,errdata,mv,xy,x,y,P,noarv,fig)
%STOCH_ERRPLOT_Q2X plots Q2 stochastic solution data on rectangular domain
%   stoch_errplot_q2x(sol,errdata,mv,xy,x,y,P,noarv,fig);
%   input
%          sol          Q2 solution vector
%          errdata      element error vector
%          mv           element mapping matrix
%          xy           vertex coordinate vector  
%          x            vector of x-axis interpolation points
%          y            vector of y-axis interpolation points
%          P            length of the index set
%          noarv        the number of active random variables
%          fig          figure number
%
%   IFISS function: DJS; 5 July 2017.
% Copyright (c) 2013 A. Bespalov, C.E. Powell, D.J. Silvester

  
%  fprintf('plotting expectation, variance and estimated errors... ')
etype=rem(fig,10);
nvtx = length(xy); mel=length(errdata);

% interpolate to a cartesian product mesh
  [X,Y] = meshgrid(x,y);

% plot the expectation of the solution
  e_xysol = griddata(xy(:,1),xy(:,2),sol(1:nvtx),X,Y);
  figure(fig)
  subplot(321),contour(X,Y,e_xysol,20),axis('square')
  axis('off'),  title('Expectation of the SFE Solution')
  subplot(322),mesh(X,Y,e_xysol),axis('square')
  view(330,30)

% compute variance of the solution
  var_sol=stoch_variance(sol,P);

% plot variance of the solution
  var_xysol = griddata(xy(:,1),xy(:,2),var_sol(1:nvtx),X,Y);
  subplot(323),contour(X,Y,var_xysol,20),axis('square')
  axis('off'),  title('Variance of the SFE Solution')
  subplot(324),mesh(X,Y,var_xysol),axis('square')
  view(330,30)

% plot a posteriori error estimate
nnxy=(length(x)-1)/2;
minx=min(x); maxx=max(x);
miny=min(y); maxy=max(y);
xx=xy(:,1); yy=xy(:,2);
xc=zeros(mel,1); yc=xc;
% loop over elements
for ielem = 1:mel
xl = xx(mv(ielem,1:4));
yl = yy(mv(ielem,1:4));
xc(ielem) = 0.25*sum(xl);
yc(ielem) = 0.25*sum(yl);
end
%---------------- corrected code
xcm=flipud(reshape(xc,nnxy,nnxy)');
ycm=flipud(reshape(yc,nnxy,nnxy)');
elm=flipud(reshape(errdata,nnxy,nnxy)');
subplot(325),contour(xcm,ycm,elm,15),axis('square')
if etype==1,title('YP estimated error'),
elseif etype==3,title('YQ estimated error'),
elseif etype==4,title('XQ estimated error'), end
subplot(326),mesh(xcm,ycm,elm),axis('square')
view(330,30)
return
