function G = stoch_gmatrices_new(indset1,indset2)
%STOCH_GMATRICES_NEW generates detail set stochastic G-matrices
%   G = stoch_gmatrices_new(indset1,indset2);
%   input
%          indset1   1st index set: a matrix of non-negative integers
%          indset2   2nd index set: a matrix of non-negative integers
%   output
%          G          a (1 x (norv+1)) cell of G-matrices
%
%   SIFISS function: DJS; 1 April 2015.
% Copyright (c) 2013 A. Bespalov, C.E. Powell, D.J. Silvester

% compute the lengths of index sets and the number of random variables
  [P1,norv] = size(indset1);
  [P2,norv] = size(indset2);

% initialisation
  G = cell(1,norv+1);
  I = eye(norv,'uint8');
%%%  P = max(P1,P2);

% compute G_0
  G{1,1} = sparse(P2,P1);
  for k=1:P2
      nu = indset2(k,:);
      n = find(ismember(indset1,nu,'rows'));
      if isempty(n)==0,
      G{1,1}(k,n) = 1;
      G{1,1}(n,k) = G{1,1}(k,n); end
  end

% compute G_1,...,G_{norv}
  for m=1:norv
      G{1,m+1} = sparse(P2,P1);
      eps_m = I(m,:);
      for k=1:P2
          nu = indset2(k,:) + eps_m;
          n = find(ismember(indset1,nu,'rows'));
          if isempty(n)==0,
          G{1,m+1}(k,n) = double(nu(m))/(sqrt(4.0e0*double(nu(m))^2-1.0e0)); end
%
          nu = indset2(k,:) - eps_m;
          n = find(ismember(indset1,nu,'rows'));
          if isempty(n)==0,
          nu = indset2(k,:);
          G{1,m+1}(k,n) = double(nu(m))/(sqrt(4.0e0*double(nu(m))^2-1.0e0)); end
      end
  end

