function [intres] = stoch_intres_q2_yp_old(xy,mv,q2sol,indset,P,norv,noarv,KL_DATA)
%STOCH_INTRES_Q2_YP_OLD  legacy code
%   [intres] = stoch_intres_q2_yp_old(xy,mv,q2sol,indset,P,norv,noarv,KL_DATA);
%   input
%          xy         vertex coordinate vector
%          mv         element mapping matrix
%          q2sol      stochastic Q2 solution vector
%          indset     index set of polynomial degrees
%          P          length of the index set
%          norv       number of random variables
%          noarv      the number of active random variables
%          KL_DATA    data related to KL-expansion
%   output
%          intres     interior residuals
%
%   calls functions gausspoints_oned, gausspoints_twod, deriv, qderiv, qqderiv
%   calls stoch_gauss_source, stoch_gauss_coeff, stoch_gauss_gradcoeff, stoch_rhs_multipliers
%   SIFISS function: DJS 2 July 2017 (modifications of T. Gergelits)
% Copyright (c) 2015 A. Bespalov, C.E. Powell, D.J. Silvester

%% taken from diffpost_q2_with_q4
reduction_level=3;
error_node=[10;11;12;13;14;15;16;17;18;20;22;24];
N_error_node=length(error_node); nn=N_error_node;

  x=xy(:,1); y=xy(:,2); nvtx=length(x);
  mel=length(mv(:,1));

% construct the integration rule
ngpt=7;
  [oneg,onew] = gausspoints_oned(ngpt);
  [s,t,wt] = gausspoints_twod(oneg,onew);
  nngpt=ngpt^2; ng=ngpt;

% inner loop over elements
  for ivtx = 1:4
      xl_v(:,ivtx) = x(mv(:,ivtx));
      yl_v(:,ivtx) = y(mv(:,ivtx));
  end
  for ivtx=1:9
      for k=1:P
          sl_v(:,ivtx+9*(k-1)) = q2sol(nvtx*(k-1)+mv(:,ivtx));
      end
  end

% initialisation
  intres = zeros(mel,nn*P);
  fde = zeros(mel,nn,norv+1);
  bde = zeros(mel,nn,9,norv+1);

% loop over Gauss points
   for igpt = 1:nngpt
   sigpt=s(igpt);
   tigpt=t(igpt);
   wght=wt(igpt);
% evaluate derivatives etc
   [jac_v,invjac_v,phi_v,dphidx_v,dphidy_v] = deriv(sigpt,tigpt,xl_v,yl_v);
   rhs = stoch_gauss_source(sigpt,tigpt,xl_v,yl_v,norv);
   [qua,dquadx,dquady] = qqderiv(sigpt,tigpt,xl_v,yl_v);
   coeff = stoch_gauss_coeff(sigpt,tigpt,xl_v,yl_v,norv,KL_DATA);
   [dcoeffdx,dcoeffdy] = stoch_gauss_gradcoeff(sigpt,tigpt,xl_v,yl_v,norv,KL_DATA);
   [psi,dpsidx,dpsidy] = qderiv(sigpt,tigpt,xl_v,yl_v);
   [dpsi2dx2,dpsi2dy2] = qderiv_2(sigpt,tigpt,xl_v,yl_v);
   deltapsi = dpsi2dx2+dpsi2dy2; 
      for m = 0:norv
         for j = 1:N_error_node
         jj=error_node(j);
% compute rhs-contributions
         fde(:,j,m+1) = fde(:,j,m+1) + wght*rhs(:,m+1) .* qua(:,jj) .* jac_v(:);
% compute div(a*grad)-contributions
             for i = 1:9  % element basis functions
             bde(:,j,i,m+1) = bde(:,j,i,m+1)+ wght*dcoeffdx(:,m+1).*dpsidx(:,i).*qua(:,jj);
             bde(:,j,i,m+1) = bde(:,j,i,m+1)+ wght*dcoeffdy(:,m+1).*dpsidy(:,i).*qua(:,jj);
             bde(:,j,i,m+1) = bde(:,j,i,m+1)+ wght*coeff(:,m+1).*deltapsi(:,i).*qua(:,jj).*invjac_v(:);
             end
          end
       end
% end of Gauss point loop
   end


% compute G-matrices and rhs-multipliers
  G = stoch_gmatrices_old(indset,P,norv);
  [rhs_ind,beta] = stoch_rhs_multipliers(indset,P,norv);

% assemble interior residuals from rhs-contributions
  for m=0:norv
      ind_m = rhs_ind(1,m+1);
      if ind_m>0
         intres(:,(nn*(ind_m-1)+1):(nn*ind_m)) = intres(:,(nn*(ind_m-1)+1):(nn*ind_m)) + ...
                                               fde(:,:,m+1)*beta(1,m+1);                                           
      end
  end

  
% assemble interior residuals from div(a*grad)-contributions
%  

%   compute local matrices and multiply them by the solution vector
for m = 0:norv
    [nzi,nzj,g] = find(G{m+1});
    for t=1:length(nzi)
        i=nzi(t); j=nzj(t);
        for ii = 1:nn
            for jj = 1:9
                intres(:,nn*(i-1)+ii) = ...
                    intres(:,nn*(i-1)+ii) + (g(t)*bde(:,ii,jj,m+1)).*sl_v(:,9*(j-1)+jj);
            end
        end
    end
end

return
