function lambda_min = stoch_test_wellposedness(norv,noarv,KL_DATA)
%STOCH_TEST_WELLPOSEDNESS   Computes lower bound of the KL-type stochastic diffusion coefficient
%   a = stoch_test_wellposedness(norv,noarv,KL_DATA)
%   input
%          norv       number of random variables
%          noarv      number of active random variables
%          KL_DATA    data related to KL-expansion
%
%   SIFISS function: AB; 10 November 2014.
% Copyright (c) 2014 A. Bespalov, C.E. Powell, D.J. Silvester

% get standard deviation
  sigma = KL_DATA.input(3);

  m = 1:noarv;
  nx = KL_DATA.ev2d_ind(m,1); ny = KL_DATA.ev2d_ind(m,2);

% get eigenvalues
  lambdas = KL_DATA.ev2d(m);

% get factors of cos/sin
  alphas_x = KL_DATA.ev_x(nx,3);
  alphas_y = KL_DATA.ev_y(ny,3);

% compute lower bound of the diffusion coefficient
  lambda_min = 1 - sigma * sqrt(3.0e0) * sum(alphas_x .* alphas_y .* sqrt(lambdas'));

