function a = stoch_specific_coeff(x,y,nel,norv,KL_DATA)
%STOCH_SPECIFIC_COEFF   synthetic stochastic diffusion coefficient
%   a = stoch_specific_coeff(x,y,nel,norv,KL_DATA)
%   input
%          x          x coordinate vector
%          y          y coordinate vector
%          nel        number of elements
%          norv       number of random variables
%          KL_DATA    data related to KL-expansion
%
% This expansion is discussed in
% M. Eigel, C.J. Gittelson, C. Schwab, E. Zander
% Adaptive stochastic FEM,
% Comput. Methods Appl. Mech. Engrg. 270:247-269, 2014.
%
%   SIFISS function: DJS; 1 April 2015.
% Copyright (c) 2013 A. Bespalov, C.E. Powell, D.J. Silvester


% initialisation
  a=zeros(nel,norv+1);

% set a_0
  a(:,1)=ones(nel,1);


% set decay rate of stochastic coefficients
sdecay = KL_DATA.decay;
if sdecay, sigma=2; alpha=0.547;
else, sigma=4; alpha=0.832;
end

% set a_m
  for m=1:norv
      km=floor(-0.5e0+sqrt(0.25e0+2*m));
      beta_x=m-km*(km+1)/2; beta_y=km-beta_x;
      a(:,m+1) = alpha / (m^(sigma)) * cos(2*pi*beta_x*x) .* cos(2*pi*beta_y*y);
  end
return

